@@ -1,7 +1,7 @@
-#$Id: DirectConnect.pm 919 2011-10-21 21:57:00Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect.pm $
+#$Id: DirectConnect.pm 936 2011-11-09 21:58:57Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect.pm $
 package Net::DirectConnect;
 use strict;
-our $VERSION = '0.11';# . '_' . ( split ' ', '$Revision: 919 $' )[1];
+our $VERSION = '0.12'; # . '_' . ( split ' ', '$Revision: 936 $' )[1];
 no warnings qw(uninitialized);
 use utf8;
 use Encode;
@@ -78,7 +78,7 @@ sub socket_addr ($) {
 }
 
 sub schedule($$;@)
-{    #$Id: DirectConnect.pm 919 2011-10-21 21:57:00Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect.pm $
+{    #$Id: DirectConnect.pm 936 2011-11-09 21:58:57Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect.pm $
   our %schedule;
   my ( $every, $func ) = ( shift, shift );
   my $p;
@@ -98,6 +98,8 @@ sub schedule($$;@)
     and ref $schedule{ $p->{'id'} }{'func'} eq 'CODE';
 }
 
+sub notone (@) { @_ = grep {$_ and $_ != 1} @_; wantarray ? @_ : $_[0]}
+
 sub use_try ($;@) {
   my $self = shift if ref $_[0];
   our %tried;
@@ -424,7 +426,7 @@ sub init_main {    #$self->{'init_main'} ||= sub {
     'wait_clients'      => 300,    #5 min
                                    #del    'wait_clients_by'    => 0.01,
                                    #'work_sleep'        => 0.01,
-    'work_sleep'        => 1,
+    'work_sleep'        => 0.005,
     'select_timeout'    => 1,
     'cmd_recurse_sleep' => 0,
     #( $^O eq 'MSWin32' ? () : ( 'nonblocking' => 1 ) ),
@@ -464,8 +466,9 @@ sub init_main {    #$self->{'init_main'} ||= sub {
     for qw(sockets share_full share_tth want want_download want_download_filename downloading);
   $self->{$_} //= $self->{'parent'}{$_} ||= $global{$_}, for qw(db);
   $self->{'parent'}{$_} ? $self->{$_} //= $self->{'parent'}{$_} : ()
-    for qw(log disconnect_recursive  partial_prefix partial_ext download_to Proto dev_ipv6 socket_class protocol);    #dev_adcs
-      #$self->log( 'dev', "Proto=$self->{Proto}, Listen=$self->{Listen} protocol=$self->{protocol}" );
+    for qw(log disconnect_recursive  partial_prefix partial_ext download_to Proto dev_ipv6 socket_class protocol myport_inc)
+    ;   #dev_adcs
+        #$self->log( 'dev', "Proto=$self->{Proto}, Listen=$self->{Listen} protocol=$self->{protocol} inc=$self->{myport_inc}" );
   $self->{$_} //= $_{$_} for keys %_;
   $self->{'partial_prefix'} //= $self->{'download_to'} . 'Incomplete/';
   #$self->log("charset_console=$self->{charset_console} charset_fs=$self->{charset_fs}");
@@ -479,6 +482,7 @@ sub myport_generate {    #$self->{'myport_generate'} ||= sub {
     unless $self->{'myport_base'}
       or $self->{'myport_random'};
   $self->{'myport'} = undef if $_[0];
+  return $self->{'myport'} ||= $self->{'myport_base'} + $self->{'myport_inc'}++ if $self->{'myport_inc'};
   return $self->{'myport'} ||= $self->{'myport_base'} + int( rand( $self->{'myport_random'} ) );
 }
 
@@ -513,7 +517,7 @@ sub connect_check {
   $self->every(
     $self->{'reconnect_sleep'},
     $self->{'reconnect_func'} ||= sub {
-      if ( $self->{'reconnect_tries'}++ <= $self->{'reconnects'} ) {
+      if ( $self->{'reconnect_tries'}++ < $self->{'reconnects'} ) {
         $self->log(
           'warn',
           "reconnecting [$self->{'reconnect_tries'}/$self->{'reconnects'}] every",
@@ -643,8 +647,8 @@ sub reconnect {    #$self->{'reconnect'} ||= sub {
   #$self->log(          'dev', 'reconnect');
   $self->disconnect();
   $self->{'status'} = 'reconnecting';
-  sleep $self->{'reconnect_sleep'};
-  $self->connect();
+  #!sleep $self->{'reconnect_sleep'};
+  #!$self->connect();
 }
 
 sub listen {       #$self->{'listen'} ||= sub {
@@ -734,6 +738,7 @@ sub destroy {
                           #!?  delete $self->{$_} for keys %$self;
   $self->info();
   $self->{'status'} = 'destroy';
+  delete $self->{$_} for grep { ref $self->{$_} and !ref $self->{$_} eq 'CODE' } keys %$self;
   #$self = {};
   #!?%$self = ();
 }
@@ -800,9 +805,12 @@ sub recv {                # $self->{'recv'} ||= sub {
     #TODO not here
     if (  $self->active()
       and !$self->{'incoming'}
-      and $self->{'reconnect_tries'}++ < $self->{'reconnects'} )
+      #and $self->{'reconnect_tries'}++ < $self->{'reconnects'} 
+      )
     {
-      $self->log( 'dcdbg', "recv err, reconnect. d=[$self->{'databuf'}] i=[$self->{'incoming'}]" );
+      $self->log( 'dcdbg',
+        "recv err, reconnect [$self->{'reconnect_tries'}/$self->{'reconnects'}]. d=[$self->{'databuf'}] i=[$self->{'incoming'}]"
+      );
       #$self->log( 'dcdbg',  "recv err, reconnect," );
       $self->reconnect();
     } elsif ( $self->{'status'} ne 'listening' ) {
@@ -861,7 +869,7 @@ sub select {    #$self->{'select'} ||= sub {
   #$self->{'select'} = IO::Select->new( $self->{'socket'} ) if !$self->{'select'} and $self->{'socket'};
   #my ( $readed, $reads );
   #$self->{'databuf'} = '';
-  #$self->log( 'dev', 'select', 'bef', $sleep, $nosend , );
+  #$self->log( 'dev', 'select', 'bef', $sleep, $nosend , ) if $nosend;
   my ( $recv, $send, $exeption ) =
     IO::Select->select( $self->{'select'}, ( $nosend ? undef : $self->{'select_send'} ), $self->{'select'}, $sleep );
 #$self->log( 'traceD', 'DC::select', 'aft' , Dumper ($recv, $send, $exeption));
@@ -873,7 +881,8 @@ sub select {    #$self->{'select'} ||= sub {
   for (@$exeption) {
     #$self->log( 'dcdbg', 'exeption', $_, $self->{sockets}{$_}{number} ),
     #$self->{'select'}->remove($_);
-    can_run( $self->{sockets}{$_}, 'destroy' );
+    #can_run( $self->{sockets}{$_}, 'destroy' );
+    can_run( $self->{sockets}{$_}, 'reconnect' );
     #$self->{sockets}{$_}->destroy() if ref $self->{sockets}{$_};
     delete $self->{sockets}{$_};
     ++$ret,;
@@ -888,6 +897,7 @@ sub select {    #$self->{'select'} ||= sub {
       if $self->{sockets}{$_}{status} eq 'connecting_tcp' and $self->{sockets}{$_}{socket}->connected();
   }
 =cut
+
   for (@$send) {
     next unless $self->{sockets}{$_} and $self->{sockets}{$_}{socket};
     $self->{sockets}{$_}->connected(),
@@ -906,7 +916,8 @@ sub select {    #$self->{'select'} ||= sub {
   }
   for (@$recv) {
     #next unless $self->{sockets}{$_};
-    $self->log( 'err', 'no object for recv handle', $_, Dumper $self->{sockets}{$_} ), $self->{'select'}->remove($_), next,
+    $self->log( 'err', 'no object for recv handle', $_, Dumper $self->{sockets}{$_} ),
+      can_run( $self->{'select'}, 'remove', $_ ), next,
       #if !$self->{sockets}{$_} or !ref $self->{sockets}{$_};
       if !ref $self->{sockets}{$_} or ref $self->{sockets}{$_} eq 'HASH';
     #$self->log( 'dev',ref $self->{sockets}{$_});
@@ -957,8 +968,8 @@ sub wait_connect {                                                         #$sel
   for ( 0 .. ( $_[0] || $self->{'wait_connect_tries'} ) ) {
     #$self->log('dev', 'ws', $self->{'status'}, $_, ( $_[0] , $self->{'wait_connect_tries'}));
     last if grep { $self->{'status'} eq $_ } qw(connected transfer disconnecting disconnected destroy), '';
-    $self->wait(1);
-    #$self->work(1);
+    #$self->wait(1);
+    $self->work(1);
   }
   return $self->{'status'};
 }
@@ -971,7 +982,8 @@ sub wait_finish {                                                          #$sel
     last if $self->finished();
     #$self->wait( undef, $self->{'wait_finish_by'} );
     #$self->log( 'dev', 'wait_finish', $_);
-    $self->wait();
+    #$self->wait();
+    $self->work(1);
     #$self->work( undef, $self->{'wait_finish_by'} );
   }
   local @_;
@@ -999,7 +1011,7 @@ sub wait_clients {                    #$self->{'wait_clients'} ||= sub {
       int( $time - time() )
     );
     #$self->wait( undef, $self->{'wait_clients_by'} );
-    $self->work(5);
+    $self->work(10);
   }
 }
 #sub wait_sleep {                                                     #$self->{'wait_sleep'} ||= sub {
@@ -1011,7 +1023,7 @@ sub wait {                                                           #$self->{'w
   while ( $time > time() ) {
     last unless $self->active();
     #$ret += $self->wait(@_);
-    $ret += $self->select( 1, 1 );
+    $ret += $self->select() || $self->select( 1, 1 );
   }
   return $ret;
   #$self->log( 'dev', "wait_sleep",$starttime , $how , time(), "==", $starttime + $how),
@@ -1050,8 +1062,8 @@ sub work {    #$self->{'work'} ||= sub {
         {
           $self->log(
             'dev',
-"del client[$self->{'clients'}{$_}{'number'}][$_] socket=[$self->{'clients'}{$_}{'socket'}] status=[$self->{'clients'}{$_}{'status'}] listener=[$self->{'listener'}]last active=",
-            time - $self->{'clients'}{$_}{activity}
+"del client[$self->{'clients'}{$_}{'number'}][$_] socket=[$self->{'clients'}{$_}{'socket'}] status=[$self->{'clients'}{$_}{'status'}] listener=[$self->{'listener'}] last active=",
+            int( time - $self->{'clients'}{$_}{activity} )
           );
           #(
           #!ref $self->{'clients'}{$_}{destroy} ? () :
@@ -1181,14 +1193,15 @@ sub work {    #$self->{'work'} ||= sub {
     },
     $self
   ) if $self->{dev_auto_dump};
-  return $self->select( $self->{'work_sleep'} );    # if @{$self->{send_buffer_raw}|| []};    # maybe send
-                                                    #$self->log( 'dev', "work -> sleep", @params ),
+  #return
+  $self->select( 1 || $self->{'work_sleep'} );    # if @{$self->{send_buffer_raw}|| []};    # maybe send
+                                             #$self->log( 'dev', "work -> sleep", @params ),
   return $self->wait(@params) if @params;
-  #return $self->select( $self->{'work_sleep'}, 1 );
-  return $self->select( $self->{'work_sleep'} );
+  return $self->select() || $self->select( $self->{'work_sleep'}, 1 );    # unless @{$self->{send_buffer_raw}|| []};
+                                                                          #return $self->select( $self->{'work_sleep'} );
 }
 
-sub dumper {                                        #$self->{'dumper'} ||= sub {
+sub dumper {                                                              #$self->{'dumper'} ||= sub {
   my $self = shift;
   my $file = $_[0] || $self->{dev_auto_dump_file} || $0 . ( $self->{dev_auto_dump_timed} ? '.' . time : () ) . '.dump';
   open my $fh, '>', $file or return;
@@ -1197,7 +1210,7 @@ sub dumper {                                        #$self->{'dumper'} ||= sub {
   $self->log( 'dev', "Writed dump", -s $file );
 }
 
-sub parser {                                        #$self->{'parser'} ||= sub {
+sub parser {                                                              #$self->{'parser'} ||= sub {
   my $self = shift;
   for ( local @_ = @_ ) {
     $self->log(
@@ -1216,6 +1229,7 @@ sub parser {                                        #$self->{'parser'} ||= sub {
       $cmd = ( $self->{'status'} eq 'connected' ? 'chatline' : 'welcome' );
     }
     s/^\$?([\w\-]+)\s*//, $cmd = $1 unless $cmd;
+    #$self->log('dev',"cmd[", Dumper($cmd),"]" );
     if ( $self->{'adc'} ) {
       $cmd =~ s/^([BCDEFHIU])//, $dst = $1;
       @param = ( [$dst], split / / );
@@ -1302,7 +1316,7 @@ sub send_can {    #$self->{'send'} ||= sub {
   eval { $size += $self->{'socket'}->$send($_) for @_ ? @_ : @{ $self->{send_buffer_raw} }; } if $self->{'socket'};
   $self->{send_buffer_raw} = [];
   $self->{bytes_send} += $size;
-  $self->log( 'err', 'send error', $@ ) if $@;
+  $self->log( 'err', 'send error', $@ ), $self->reconnect(), return $size if $@;
   $self->{activity} = time;
   return $size;
 }
@@ -1326,7 +1340,6 @@ sub send {    #$self->{'send'} ||= sub {
 	$self->{send_buffer_raw} = undef;
     }
 =cut
-
   #return unless @_;
 }
 
@@ -1542,8 +1555,8 @@ sub file_write {    #$self->{'file_write'} ||= sub {
           'dev',                              "recv bytes",           #length $self->{'file_send_buf'},
           "recv=[$recv] now [",               $self->{'filebytes'},
           "] of [$self->{'filetotal'}], now", 's=',
-          ( $self->{'filebytes'} - $self->{__stat_recv_lastmark} ) /
-            ( time - $self->{__stat_recv_lasttime} or 1 ),
+          int( ( $self->{'filebytes'} - $self->{__stat_recv_lastmark} ) /
+              ( time - $self->{__stat_recv_lasttime} or 1 ) ),
           "status=[$self->{'status'}]",
           ),
           $self->{__stat_recv_lastmark} = $self->{'filebytes'};
@@ -1722,8 +1735,8 @@ sub file_send_part {    #$self->{'file_send_part'} ||= sub {
         "] by [$read:$self->{'file_send_by'}] left $self->{'file_send_left'}, now",
         $self->{'file_send_offset'}, 'of',
         $self->{'file_send_total'},  's=',
-        ( $self->{'file_send_offset'} - $self->{__stat_lastmark} ) /
-          ( time - $self->{__stat_lasttime} or 1 ),
+        int( ( $self->{'file_send_offset'} - $self->{__stat_lastmark} ) /
+            ( time - $self->{__stat_lasttime} or 1 ) ),
         "status=[$self->{'status'}]",
         ),
         $self->{__stat_lastmark} = $self->{'file_send_offset'};
@@ -1829,7 +1842,6 @@ sub get_peer_addr {    #$self->{'get_peer_addr'} ||= sub () {
     if $_[1];
   return $self->{'hostip'};
 =cut
-
 }
 
 sub get_peer_addr_recv {    #$self->{'get_peer_addr_recv'} ||= sub (;$) {
@@ -1864,6 +1876,7 @@ sub get_my_addr {           #$self->{'get_my_addr'} ||= sub {
   #$self->{'log'}->('dev', "MYIP($self->{'myip'}) [$self->{'number'}] SOCKNAME $_[0],$_[1];");
   return $self->{'myip'} ||= $_[1];
 =cut
+
 }
 
 sub info {    #$self->{'info'} ||= sub {
