@@ -1,4 +1,4 @@
-#$Id: clihub.pm 919 2011-10-21 21:57:00Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect/clihub.pm $
+#$Id: clihub.pm 933 2011-11-03 22:53:27Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/lib/Net/DirectConnect/clihub.pm $
 package    #hide from cpan
   Net::DirectConnect::clihub;
 use strict;
@@ -10,7 +10,7 @@ use Net::DirectConnect;
 use Net::DirectConnect::clicli;
 #use Net::DirectConnect::http;
 no warnings qw(uninitialized);
-our $VERSION = ( split( ' ', '$Revision: 919 $' ) )[1];
+our $VERSION = ( split( ' ', '$Revision: 933 $' ) )[1];
 use base 'Net::DirectConnect';
 
 sub name_to_ip($) {
@@ -131,7 +131,8 @@ sub init {
           or $text =~
           /Пожалуйста подождите (\d+) секунд до повторного подключения\./ )
         {
-          sleep $1 + 1;
+          #sleep $1 + 1;
+          $self->work( $1 + 10 );
         } elsif ( $self->{'auto_bug'} and $nick eq 'VerliHub' and $text =~ /^This Hub Is Running Version 0.9.8d/i ) {    #_RC1
           ++$self->{'bug_MyINFO_last'};
           $self->log( 'dev', "possible bug fixed [$self->{'bug_MyINFO_last'}]" );
@@ -404,7 +405,6 @@ sub init {
 
 
 =cut  
-
   #$self->{'cmd'} = {
   local %_ = (
     'connect_aft' => sub {
@@ -626,7 +626,6 @@ sub init {
     $self->log( 'err', "cant listen http" )
       unless $self->{'myport_http'};
 =cut
-
   $self->{'handler_int'}{'disconnect_bef'} = sub {
     #delete $self->{'sid'};
     #$self->log( 'dev', 'disconnect int' ) if $self and $self->{'log'};
